@@ -1,8 +1,10 @@
 import io
 import json
+import plotly
 import numpy as np
 
 from typing import Any
+
 from ai_dashboard.tabs.data_report.blocks.base import BaseBlock
 
 
@@ -42,11 +44,11 @@ class Plotly(BaseBlock):
                 {
                     "attrs": {
                         "height": "auto",
-                        "data": fig._data,
                         "layout": layout,
                         "options": options,
                         "title": title,
                         "width": f"{width_percentage}%",
+                        **json.loads(plotly.io.to_json(fig)),
                     },
                     "type": "plotlyChart",
                 }
